/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.call.test;

import static org.junit.Assert.*;

import org.junit.Test;

import static dk.vajhoej.vms.call.VMS.*;

import dk.vajhoej.vms.call.VMSLibrary.Result;
import dk.vajhoej.vms.call.lib.LIBRTL;

public class TestBasic extends BaseTest {
	@Test
	public void testDefaultAccessTraditionalStyle() {
        try {
            CharacterString buf = new CharacterString(255);
            Word retlen = new Word();
            int sts = call("LIBRTL", "LIB$GET_LOGICAL", byDescriptor(new CharacterString("SYS$DISK")),
            		                                    byDescriptor(buf),
            		                                    byReference(retlen));
            String res = createString(buf, retlen);
            assertVMSCall("GET_LOGICAL SYS$DISK default access traditional style", sts, res);
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
	@Test
	public void testExplicitAccessTraditionalStyle() {
        try {
            CharacterString buf = new CharacterString(255);
            Word retlen = new Word();
            int sts = call("LIBRTL", "LIB$GET_LOGICAL", readOnly(byDescriptor(new CharacterString("SYS$DISK"))),
            		                                    writeOnly(byDescriptor(buf)),
            		                                    writeOnly(byReference(retlen)));
            String res = createString(buf, retlen);
            assertVMSCall("GET_LOGICAL SYS$DISK explicit access traditional style", sts, res);
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
	@Test
	public void testDefaultAccessFluentStyle() {
        try {
            CharacterString buf = new CharacterString(255);
            Word retlen = new Word();
            int sts = call("LIBRTL", "LIB$GET_LOGICAL", pass(new CharacterString("SYS$DISK")).byDescriptor(),
            		                                    pass(buf).byDescriptor(),
            		                                    pass(retlen).byReference());
            String res = createString(buf, retlen);
            assertVMSCall("GET_LOGICAL SYS$DISK default access fluent style", sts, res);
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
	@Test
	public void testExplicitAccessFluentStyle() {
        try {
            CharacterString buf = new CharacterString(255);
            Word retlen = new Word();
            int sts = call("LIBRTL", "LIB$GET_LOGICAL", pass(new CharacterString("SYS$DISK")).byDescriptor().readOnly(),
                                                        pass(buf).byDescriptor().writeOnly(),
                                                        pass(retlen).byReference().writeOnly());
            String res = createString(buf, retlen);
            assertVMSCall("GET_LOGICAL SYS$DISK explicit access fluent style", sts, res);
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
	@Test
	public void testLibrary() {
        try {
        	Result<String> res = LIBRTL.LIB$GET_LOGICAL("SYS$DISK");
            assertVMSCall("GET_LOGICAL SYS$DISK library", res.getStatus(), res.getResult());
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
}
