/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.call.test;

import static org.junit.Assert.*;

import org.junit.Test;

import static dk.vajhoej.vms.call.VMS.*;
import static dk.vajhoej.vms.call.lib.VMSCodes.*;

import dk.vajhoej.vms.call.VMSLibrary.Result;
import dk.vajhoej.vms.call.lib.LBRRTL.LBR_IDX;

public class TestLBRRTL extends BaseTest {
	@Test
	public void testGET_RECORD() {
        try {
        	LBR_IDX lbridx = new LBR_IDX();
        	Result<Void> vres;
        	vres = lbridx.LBR$INI_CONTROL(LBR$C_READ, LBR$C_TYP_TXT);
        	assertVMSCall("LBR$INI_CONTROL", vres.getStatus());
        	vres = lbridx.LBR$OPEN("SYS$LIBRARY:SYS$STARLET_C.TLB");
        	assertVMSCall("LBR$OPEN", vres.getStatus());
        	vres = lbridx.LBR$LOOKUP_KEY("LBR$ROUTINES");
        	assertVMSCall("LBR$LOOKUP_KEY", vres.getStatus());
        	Result<String> sres;
        	sres = lbridx.LBR$GET_RECORD();
        	assertVMSCall("LBR$GET_RECORD", sres.getStatus(), sres.getResult());
        	sres = lbridx.LBR$GET_RECORD();
        	assertVMSCall("LBR$GET_RECORD", sres.getStatus(), sres.getResult());
        	sres = lbridx.LBR$GET_RECORD();
        	assertVMSCall("LBR$GET_RECORD", sres.getStatus(), sres.getResult());
        	int n = 0;
        	while(isSuccess(lbridx.LBR$GET_RECORD().getStatus())) n++;
        	if(System.getProperty("test.debug") != null) System.out.printf("+%d more records\n", n);
        	vres = lbridx.LBR$CLOSE();
        	assertVMSCall("LBR$CLOSE", vres.getStatus());
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
	@Test
	public void testGET_HELP() {
        try {
        	LBR_IDX lbridx = new LBR_IDX();
        	Result<Void> vres;
        	vres = lbridx.LBR$INI_CONTROL(LBR$C_READ, LBR$C_TYP_HLP);
        	assertVMSCall("LBR$INI_CONTROL", vres.getStatus());
        	vres = lbridx.LBR$OPEN("SYS$HELP:HELPLIB.HLB");
        	assertVMSCall("LBR$OPEN", vres.getStatus());
        	Result<String> sres;
        	sres = lbridx.LBR$GET_HELP("COPY", "/LOG");
        	assertVMSCall("LBR$GET_HELP", sres.getStatus(), sres.getResult());
        	vres = lbridx.LBR$CLOSE();
        	assertVMSCall("LBR$CLOSE", vres.getStatus());
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
}
