/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.call.test;

import java.util.List;
import java.util.Map;

import static org.junit.Assert.*;

import org.junit.Test;

import static dk.vajhoej.vms.call.lib.VMSCodes.*;
import static dk.vajhoej.vms.call.lib.VMSStatus.*;

import dk.vajhoej.vms.call.VMSLibrary.Result;
import dk.vajhoej.vms.call.lib.SYS;
import dk.vajhoej.vms.call.lib.SYS_Util;

public class TestSYS extends BaseTest {
	@Test
	public void testPROCESS_SCAN() {
        try {
        	Result<Integer> res = SYS.SYS$PROCESS_SCAN(PSCAN$_USERNAME, "*");
        	assertVMSCall("PROCESS_SCAN USERNAME=*", res.getStatus());
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
	@Test
	public void testGETJPIW() {
        try {
			Result<Map<Integer,Object>> res = SYS.SYS$GETJPIW(0, new int[] { JPI$_PID, JPI$_USERNAME, JPI$_PRCNAM, JPI$_CPUTIM });
			assertVMSCall("GETJPIW pid=0", res.getStatus(), res.getResult());
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
	@Test
	public void testPROCESS_SCAN_GETJPIW() {
        try {
        	List<Map<Integer,Object>> res = SYS_Util.SYS$PROCESS_SCAN_and_SYS$GETJPIW(PSCAN$_USERNAME, "*", new int[] { JPI$_PID, JPI$_USERNAME, JPI$_PRCNAM, JPI$_CPUTIM });
			assertVMSCall("PROCESS_SCAN USERNAME=* GETJPIW res=%s\n", SS$_NORMAL, res);
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
	@Test
	public void testGETDVIW() {
        try {
			Result<Map<Integer,Object>> res = SYS.SYS$GETDVIW("SYS$DISK", new int[] { DVI$_VOLNAM, DVI$_MAXBLOCK, DVI$_FREEBLOCKS });
			assertVMSCall("GETDVIW devnam=SYS$DISK", res.getStatus(), res.getResult());
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
	@Test
	public void testGETUAI() {
        try {
			Result<Map<Integer,Object>> res = SYS.SYS$GETUAI("ARNE", new int[] { UAI$_OWNER, UAI$_DEFDEV, UAI$_DEFDIR, UAI$_UIC });
			assertVMSCall("GETUAI usrnam=ARNE", res.getStatus(), res.getResult());
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
	@Test
	public void testIDTOASC() {
        try {
        	int id = (Integer)SYS.SYS$GETJPIW(0, new int[] { JPI$_UIC }).getResult().get(JPI$_UIC);
        	Result<String> res = SYS.SYS$IDTOASC(id);
        	assertVMSCall("IDTOASC ID=me", res.getStatus(), res.getResult());
        	Map<Integer,String> res2 = SYS_Util.SYS$IDTOASC(true);
        	assertVMSCall("IDTOASC ID=*\n", SS$_NORMAL, res2);
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
	@Test
	public void testASCTIM() {
        try {
			Result<String> res = SYS.SYS$ASCTIM();
			assertVMSCall("ASCTIM", res.getStatus(), res.getResult());
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
	@Test
	public void testGETTIM() {
        try {
			Result<Long> res = SYS.SYS$GETTIM();
			assertVMSCall("GETTIM", res.getStatus(), res.getResult());
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
	@Test
	public void testGETTIM_ASCTIM_BINTIM() {
        try {
			Result<Long> lres = SYS.SYS$GETTIM();
			assertVMSCall("GETTIM", lres.getStatus(), lres.getResult());
			Result<String> sres = SYS.SYS$ASCTIM(lres.getResult());
			assertVMSCall("ASCTIM", sres.getStatus(), sres.getResult());
			Result<Long> lres2 = SYS.SYS$BINTIM(sres.getResult());
			assertVMSCall("BINTIM", lres2.getStatus(), lres2.getResult());
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
}
